Function ratatui_destroy

#[no_mangle]
pub extern "C" fn ratatui_destroy(handle: *mut c_void)
Destroys a terminal handle created by ratatui_create.

After this call the handle and any previously returned pixel-buffer pointers are invalid and must not be used. A null handle is a no-op.